@@ -36,10 +36,10 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '7.4.2-11-n.js';
+gTestfile = '7.4.2-14-n.js';
 
 /**
-   File Name:          7.4.2-11-n.js
+   File Name:          7.4.2-14-n.js
    ECMA Section:       7.4.2
 
    Description:
@@ -62,16 +62,16 @@ gTestfile = '7.4.2-11-n.js';
    Date:               12 november 1997
 
 */
-var SECTION = "7.4.1-11-n";
+var SECTION = "7.4.1-14-n";
 var VERSION = "ECMA_1";
 startTest();
 var TITLE   = "Keywords";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-DESCRIPTION = "var this = true";
+DESCRIPTION = "var in = true";
 EXPECTED = "error";
 
-new TestCase( SECTION,  "var this = true",     "error",    eval("var this = true") );
+new TestCase( SECTION,  "var in = true",     "error",    eval("var in = true") );
 
 test();
